@@ -1,9 +1,7 @@
 package HTML::FormFu;
-{
-  $HTML::FormFu::VERSION = '1.00';
-}
+$HTML::FormFu::VERSION = '2.01';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::Render',
     'HTML::FormFu::Role::CreateChildren',
@@ -86,7 +84,7 @@ has languages => (
     default => sub { ['en'] },
     lazy    => 1,
     isa     => 'ArrayRef',
-    traits  => ['Chained'],
+    traits  => ['FormFuChained'],
 );
 
 has input => (
@@ -94,7 +92,7 @@ has input => (
     default => sub { {} },
     lazy    => 1,
     isa     => 'HashRef',
-    traits  => ['Chained'],
+    traits  => ['FormFuChained'],
 );
 
 has _processed_params => (
@@ -129,12 +127,12 @@ our @MULTIFORM_SHARED = (qw(
 for (@MULTIFORM_SHARED) {
     has $_ => (
         is     => 'rw',
-        traits => ['Chained'],
+        traits => ['FormFuChained'],
     );
 }
 
-has submitted => ( is => 'rw', traits => ['Chained'] );
-has query     => ( is => 'rw', traits => ['Chained'] );
+has submitted => ( is => 'rw', traits => ['FormFuChained'] );
+has query     => ( is => 'rw', traits => ['FormFuChained'] );
 
 has _auto_fieldset => ( is => 'rw' );
 
@@ -1241,10 +1239,10 @@ distribution.
 If you're using L<Catalyst>, a more suitable example might be:
 
     package MyApp::Controller::User;
-    use strict;
-    use base 'Catalyst::Controller::HTML::FormFu';
+    use Moose;
+    extends 'Catalyst::Controller::HTML::FormFu';
 
-    sub user : Chained CaptureArgs(1) {
+    sub user : FormFuChained CaptureArgs(1) {
         my ( $self, $c, $id ) = @_;
 
         my $rs = $c->model('Schema')->resultset('User');
@@ -1254,7 +1252,7 @@ If you're using L<Catalyst>, a more suitable example might be:
         return;
     }
 
-    sub edit : Chained('user') Args(0) FormConfig {
+    sub edit : FormFuChained('user') Args(0) FormConfig {
         my ( $self, $c ) = @_;
 
         my $form = $c->stash->{form};
@@ -2488,12 +2486,21 @@ See L<HTML::FormFu::Plugin> for details.
 =head1 ADVANCED CUSTOMISATION
 
 By default, formfu renders "XHTML 1.0 Strict" compliant markup, with as
-little extra markup as possible, but with sufficient CSS class names to allow
-for a wide-range of output styles to be generated by changing only the CSS.
+little extra markup as possible. Many hooks are provided to add
+programatically-generated CSS class names, to allow for a wide-range of
+output styles to be generated by changing only the CSS.
 
-If you wish to customise the markup, you'll need to tell HTML::FormFu to use
-an external rendering engine, such as L<Template Toolkit|Template> or
-L<Template::Alloy>. See L</render_method> and L</tt_module> for details.
+Basic customisation of the markup is possible via the 
+L<layout|HTML::FormFu::Role::Element::Field/layout> and
+L<multi_layout|HTML::FormFu::Role::Element::Field/multi_layout> methods.
+This allows you to reorder the position of various parts of each field - 
+such as the label, comment, error messages and the input tag - as well
+as inserting any other arbitrary tags you may wish.
+
+If this is not sufficient, you can make completely personalise the markup 
+by telling HTML::FormFu to use an external rendering engine, such as 
+L<Template Toolkit|Template> or L<Template::Alloy>.
+See L</render_method> and L</tt_module> for details.
 
 Even if you set HTML::FormFu to use L<Template::Toolkit|Template> to render,
 the forms, HTML::FormFu can still be used in conjunction with whichever other
@@ -3083,7 +3090,7 @@ the legacy features.
 C<v1.00> dropped most of the default HTML class-names, with the intention
 that each application should define just what it needs, without needing to
 reset unwanted options first. We also gain the benefit of less markup being
-generated, speeding up both L<render|/render> and HTTP tranfers.
+generated, speeding up both L<render|/render> and HTTP transfers.
 
 To restore the previous behaviour, set the following options.
 
@@ -3099,6 +3106,10 @@ these once per-application in your app-wide config file.
     auto_container_per_error_class: 'error_%s_%t'
     auto_error_class: 'error_message error_%s_%t'
 
+=head1 DEPRECATED METHODS
+
+See L<HTML::FormFu::Role::Element::Field/"DEPRECATED METHODS">.
+
 =head1 REMOVED METHODS
 
 See also L<HTML::FormFu::Element/"REMOVED METHODS">.
