@@ -1,9 +1,7 @@
 package HTML::FormFu::Deflator;
-{
-  $HTML::FormFu::Deflator::VERSION = '1.00';
-}
+$HTML::FormFu::Deflator::VERSION = '2.01';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::Populate';
 
@@ -11,7 +9,7 @@ use HTML::FormFu::Attribute qw( mk_inherited_accessors );
 use HTML::FormFu::ObjectUtil qw( form name parent );
 use Carp qw( croak );
 
-has type => ( is => 'rw', traits => ['Chained'] );
+has type => ( is => 'rw', traits => ['FormFuChained'] );
 
 __PACKAGE__->mk_inherited_accessors(qw( locale ));
 
