@@ -1,4 +1,5 @@
 package HTML::FormFu::Element::Image;
+$HTML::FormFu::Element::Image::VERSION = '2.01';
 use Moose;
 
 extends 'HTML::FormFu::Element::Button';
@@ -41,8 +42,8 @@ Image button form field.
 
 Is a sub-class of, and inherits methods from 
 L<HTML::FormFu::Element::Button>, 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
