@@ -1,16 +1,20 @@
 package HTML::FormFu::Element::Text;
+$HTML::FormFu::Element::Text::VERSION = '2.01';
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::_Input';
-use mro 'c3';
+extends 'HTML::FormFu::Element';
 
-sub new {
-    my $self = shift->next::method(@_);
+with 'HTML::FormFu::Role::Element::Input';
+
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('text');
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -31,8 +35,8 @@ Text form field.
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>.
 
 L<HTML::FormFu>
