@@ -1,14 +1,11 @@
 package HTML::FormFu::Element::Textarea;
-{
-  $HTML::FormFu::Element::Textarea::VERSION = '1.00';
-}
+$HTML::FormFu::Element::Textarea::VERSION = '2.01';
 use Moose;
 
 extends "HTML::FormFu::Element";
 
 with 'HTML::FormFu::Role::Element::Field',
-    'HTML::FormFu::Role::Element::SingleValueField' =>
-    { -excludes => 'nested_name' };
+    'HTML::FormFu::Role::Element::SingleValueField';
 
 use HTML::FormFu::Util qw( process_attrs );
 
@@ -23,39 +20,13 @@ __PACKAGE__->mk_attr_accessors(qw(
 after BUILD => sub {
     my $self = shift;
 
-    $self->filename('input');
-    $self->field_filename('textarea_tag');
+    $self->layout_field_filename('field_layout_textarea_field');
     $self->cols(40);
     $self->rows(20);
 
     return;
 };
 
-sub string {
-    my ( $self, $args ) = @_;
-
-    $args ||= {};
-
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
-
-    # field wrapper template - start
-
-    my $html = $self->_string_field_start($render);
-
-    # input_tag template
-
-    $html .= $self->_string_field($render);
-
-    # field wrapper template - end
-
-    $html .= $self->_string_field_end($render);
-
-    return $html;
-}
-
 sub _string_field {
     my ( $self, $render ) = @_;
 
