@@ -1,9 +1,7 @@
 package HTML::FormFu::Literal;
-{
-  $HTML::FormFu::Literal::VERSION = '1.00';
-}
-
+$HTML::FormFu::Literal::VERSION = '2.01';
 use strict;
+use warnings;
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
 use overload
