@@ -1,17 +1,15 @@
 package HTML::FormFu::QueryType::Catalyst;
-{
-  $HTML::FormFu::QueryType::Catalyst::VERSION = '1.00';
-}
+$HTML::FormFu::QueryType::Catalyst::VERSION = '2.01';
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 
 extends 'HTML::FormFu::Upload';
 
 use IO::File ();
 use Scalar::Util qw( weaken );
 
-has basename => ( is => 'rw', traits => ['Chained'] );
-has tempname => ( is => 'rw', traits => ['Chained'] );
+has basename => ( is => 'rw', traits => ['FormFuChained'] );
+has tempname => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub parse_uploads {
     my ( $class, $form, $name ) = @_;
