@@ -1,9 +1,10 @@
 package HTML::FormFu::Transformer::Callback;
-
+$HTML::FormFu::Transformer::Callback::VERSION = '2.01';
 use Moose;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Transformer';
 
-has callback => ( is => 'rw', traits => ['Chained'] );
+has callback => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub transformer {
     my ( $self, $value, $params ) = @_;
